==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/ItemToolTipLayerDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AnnotationLayerDescriptionMetadata } from "./AnnotationLayerDescriptionMetadata";
import { ItemToolTipLayerDescription } from "./ItemToolTipLayerDescription";
/**
 * @hidden
 */
var ItemToolTipLayerDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ItemToolTipLayerDescriptionMetadata, _super);
    function ItemToolTipLayerDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ItemToolTipLayerDescriptionMetadata.b = function (a) {
        if (ItemToolTipLayerDescriptionMetadata.a == null) {
            ItemToolTipLayerDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ItemToolTipLayerDescriptionMetadata.c(ItemToolTipLayerDescriptionMetadata.a);
        }
        if (a.g(ItemToolTipLayerDescriptionMetadata.a)) {
            return;
        }
        a.s(ItemToolTipLayerDescriptionMetadata.a);
    };
    ItemToolTipLayerDescriptionMetadata.c = function (a) {
        AnnotationLayerDescriptionMetadata.c(a);
        a.item("TargetSeriesName", "String");
        a.item("TargetSeriesRef", "(w:TargetSeries,wf:TargetSeries)DataRef::object");
        a.item("UseInterpolation", "Boolean");
        a.item("SkipUnknownValues", "Boolean");
    };
    ItemToolTipLayerDescriptionMetadata.d = function (a) {
        ItemToolTipLayerDescriptionMetadata.b(a);
        a.u("ItemToolTipLayer", function () { return new ItemToolTipLayerDescription(); });
        a.t("ItemToolTipLayer", ItemToolTipLayerDescriptionMetadata.a);
    };
    ItemToolTipLayerDescriptionMetadata.$t = markType(ItemToolTipLayerDescriptionMetadata, 'ItemToolTipLayerDescriptionMetadata');
    ItemToolTipLayerDescriptionMetadata.a = null;
    return ItemToolTipLayerDescriptionMetadata;
}(Base));
export { ItemToolTipLayerDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/ItemToolTipLayerDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AnnotationLayerDescriptionMetadata } from "./AnnotationLayerDescriptionMetadata";
import { ItemToolTipLayerDescription } from "./ItemToolTipLayerDescription";
/**
 * @hidden
 */
var ItemToolTipLayerDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ItemToolTipLayerDescriptionMetadata, _super);
    function ItemToolTipLayerDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ItemToolTipLayerDescriptionMetadata.b = function (a) {
        if (ItemToolTipLayerDescriptionMetadata.a == null) {
            ItemToolTipLayerDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ItemToolTipLayerDescriptionMetadata.c(ItemToolTipLayerDescriptionMetadata.a);
        }
        if (a.j(ItemToolTipLayerDescriptionMetadata.a)) {
            return;
        }
        a.y(ItemToolTipLayerDescriptionMetadata.a);
    };
    ItemToolTipLayerDescriptionMetadata.c = function (a) {
        AnnotationLayerDescriptionMetadata.c(a);
        a.item("TargetSeriesName", "String");
        a.item("TargetSeriesRef", "(w:TargetSeries,wf:TargetSeries)DataRef::object");
        a.item("UseInterpolation", "Boolean");
        a.item("SkipUnknownValues", "Boolean");
    };
    ItemToolTipLayerDescriptionMetadata.d = function (a) {
        ItemToolTipLayerDescriptionMetadata.b(a);
        a.aa("ItemToolTipLayer", function () { return new ItemToolTipLayerDescription(); });
        a.z("ItemToolTipLayer", ItemToolTipLayerDescriptionMetadata.a);
    };
    ItemToolTipLayerDescriptionMetadata.$t = markType(ItemToolTipLayerDescriptionMetadata, 'ItemToolTipLayerDescriptionMetadata');
    ItemToolTipLayerDescriptionMetadata.a = null;
    return ItemToolTipLayerDescriptionMetadata;
}(Base));
export { ItemToolTipLayerDescriptionMetadata };
